@@ -1,3 +1,5 @@
+import typing
+
 example_grids = """
 arima = {
 	'order':[(2,1,0),(0,1,2),(1,1,1)],
@@ -13,13 +15,12 @@ elasticnet = {
 
 gbt = {
 	'max_depth':[2,3],
-    'max_features':['sqrt',None]
+	'max_features':['sqrt',None]
 }
 
 hwes = {
 	'trend':['add','mul'],
-	'seasonal':['add','mul'],
-	'damped_trend':[True,False]
+	'seasonal':['add','mul']
 }
 
 knn = {
@@ -27,20 +28,21 @@ knn = {
 	'weights':['uniform','distance']
 }
 
+
 lightgbm = {
-	'max_depth':[-1,2,3]
+	'max_depth':[2,3]
 }
 
 mlp = {
 	'activation':['relu','tanh'],
 	'hidden_layer_sizes':[(25,),(25,25,)],
 	'solver':['lbfgs','adam'],
-	'normalizer':['scale','minmax',None],
+	'normalizer':['pt','minmax'],
 	'random_state':[20]
 }
 
 mlr = {
-	'normalizer':['scale','minmax','normalize',None]
+	'normalizer':['scale','minmax','pt',None]
 }
 
 prophet = {
@@ -58,8 +60,8 @@ silverkite = {
 
 svr={
 	'kernel':['linear'],
-    'C':[.5,1,2,3],
-    'epsilon':[0.01,0.1,0.5]
+	'C':[.5,1,2,3],
+	'epsilon':[0.01,0.1,0.5]
 }
 
 xgboost = {
@@ -83,7 +85,6 @@ svr={}
 xgboost = {}
 """
 
-
 import os
 
 def get_example_grids(overwrite=False):
